==> kamaqi-0.1.6.tar.gz: kamaqi-0.1.6/kamaqi/templates/migrations/migrations_env.py <==
MIGRATIONS_ENV = \
"""
from logging.config import fileConfig
from sqlalchemy import engine_from_config
from sqlalchemy import pool
from database.models import Base
from {{project_name}}.settings import get_database_string_conection
from alembic import context

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config
config.set_main_option("sqlalchemy.url",get_database_string_conection())

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:

    #Run migrations in 'offline' mode.
    #This configures the context with just a URL
    #and not an Engine, though an Engine is acceptable
    #here as well.  By skipping the Engine creation
    #we don't even need a DBAPI to be available.
    #Calls to context.execute() here emit the given string to the
    #script output.

    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:

    #Run migrations in 'online' mode.
    #In this scenario we need to create an Engine
    #and associate a connection with the context.

    
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

"""

==> kamaqi-0.1.7.tar.gz: kamaqi-0.1.7/kamaqi/templates/migrations/migrations_env.py <==
MIGRATIONS_ENV = \
"""
from logging.config import fileConfig
from sqlalchemy import engine_from_config
from sqlalchemy import pool
from database.models import Base
from {{project_name}}.settings import get_database_string_connection
from alembic import context

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config
config.set_main_option("sqlalchemy.url",get_database_string_connection())

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:

    #Run migrations in 'offline' mode.
    #This configures the context with just a URL
    #and not an Engine, though an Engine is acceptable
    #here as well.  By skipping the Engine creation
    #we don't even need a DBAPI to be available.
    #Calls to context.execute() here emit the given string to the
    #script output.

    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:

    #Run migrations in 'online' mode.
    #In this scenario we need to create an Engine
    #and associate a connection with the context.

    
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

"""
